@@ -7,8 +7,10 @@ Example beacon to use with salt-proxy
       proxy_example:
         endpoint: beacon
 """
+
 import logging
 
+import salt.utils.beacons
 import salt.utils.http
 
 # Important: If used with salt-proxy
@@ -33,14 +35,14 @@ def validate(config):
     Validate the beacon configuration
     """
     if not isinstance(config, list):
-        return False, ("Configuration for proxy_example beacon must be a list.")
+        return False, "Configuration for proxy_example beacon must be a list."
     return True, "Valid beacon configuration"
 
 
 def beacon(config):
     """
     Called several times each second
-    https://docs.saltstack.com/en/latest/topics/beacons/#the-beacon-function
+    https://docs.saltproject.io/en/latest/topics/beacons/#the-beacon-function
 
     .. code-block:: yaml
 
@@ -54,9 +56,8 @@ def beacon(config):
     # please be advised that doing CPU or IO intensive
     # operations in this method will cause the beacon loop
     # to block.
-    _config = {}
-    list(map(_config.update, config))
+    config = salt.utils.beacons.list_to_dict(config)
 
-    beacon_url = "{}{}".format(__opts__["proxy"]["url"], _config["endpoint"])
+    beacon_url = "{}{}".format(__opts__["proxy"]["url"], config["endpoint"])
     ret = salt.utils.http.query(beacon_url, decode_type="json", decode=True)
     return [ret["dict"]]
