@@ -11,6 +11,7 @@ Module to manage filesystem snapshots with snapper
 :maturity:      new
 :platform:      Linux
 """
+
 import difflib
 import logging
 import os
@@ -333,7 +334,7 @@ def create_config(
 
     def raise_arg_error(argname):
         raise CommandExecutionError(
-            'You must provide a "{}" for the new configuration'.format(argname)
+            f'You must provide a "{argname}" for the new configuration'
         )
 
     if not name:
@@ -365,7 +366,7 @@ def create_snapshot(
     description=None,
     cleanup_algorithm="number",
     userdata=None,
-    **kwargs
+    **kwargs,
 ):
     """
     Creates an snapshot
@@ -407,7 +408,7 @@ def create_snapshot(
 
     jid = kwargs.get("__pub_jid")
     if description is None and jid is not None:
-        description = "salt job {}".format(jid)
+        description = f"salt job {jid}"
 
     if jid is not None:
         userdata["salt_jid"] = jid
@@ -432,9 +433,7 @@ def create_snapshot(
                 config, pre_number, description, cleanup_algorithm, userdata
             )
         else:
-            raise CommandExecutionError(
-                "Invalid snapshot type '{}'".format(snapshot_type)
-            )
+            raise CommandExecutionError(f"Invalid snapshot type '{snapshot_type}'")
     except dbus.DBusException as exc:
         raise CommandExecutionError(
             "Error encountered while listing changed files: {}".format(
@@ -524,9 +523,9 @@ def modify_snapshot(
     try:
         # Updating only the explicitly provided attributes by the user
         updated_opts = {
-            "description": description
-            if description is not None
-            else snapshot["description"],
+            "description": (
+                description if description is not None else snapshot["description"]
+            ),
             "cleanup": cleanup if cleanup is not None else snapshot["cleanup"],
             "userdata": userdata if userdata is not None else snapshot["userdata"],
         }
@@ -559,7 +558,7 @@ def _is_text_file(filename):
         ["file", "-bi", filename],
         check=False,
         stdout=subprocess.PIPE,
-        universal_newlines=True,
+        text=True,
     ).stdout
     return type_of_file.startswith("text")
 
@@ -605,7 +604,7 @@ def run(function, *args, **kwargs):
         salt '*' snapper.run file.append args='["/etc/motd", "some text"]'
     """
     config = kwargs.pop("config", "root")
-    description = kwargs.pop("description", "snapper.run[{}]".format(function))
+    description = kwargs.pop("description", f"snapper.run[{function}]")
     cleanup_algorithm = kwargs.pop("cleanup_algorithm", "number")
     userdata = kwargs.pop("userdata", {})
 
@@ -618,11 +617,11 @@ def run(function, *args, **kwargs):
         description=description,
         cleanup_algorithm=cleanup_algorithm,
         userdata=userdata,
-        **kwargs
+        **kwargs,
     )
 
     if function not in __salt__:
-        raise CommandExecutionError('function "{}" does not exist'.format(function))
+        raise CommandExecutionError(f'function "{function}" does not exist')
 
     try:
         ret = __salt__[function](*args, **func_kwargs)
@@ -636,7 +635,7 @@ def run(function, *args, **kwargs):
         description=description,
         cleanup_algorithm=cleanup_algorithm,
         userdata=userdata,
-        **kwargs
+        **kwargs,
     )
     return ret
 
@@ -754,7 +753,7 @@ def undo(config="root", files=None, num_pre=None, num_post=None):
         return ret
     except ValueError as exc:
         raise CommandExecutionError(
-            "Error while processing Snapper response: {}".format(cmdret)
+            f"Error while processing Snapper response: {cmdret}"
         )
 
 
@@ -772,7 +771,7 @@ def _get_jid_snapshots(jid, config="root"):
     post_snapshot = [x for x in jid_snapshots if x["type"] == "post"]
 
     if not pre_snapshot or not post_snapshot:
-        raise CommandExecutionError("Jid '{}' snapshots not found".format(jid))
+        raise CommandExecutionError(f"Jid '{jid}' snapshots not found")
 
     return (pre_snapshot[0]["id"], post_snapshot[0]["id"])
 
