@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Pull sdb values from a YAML file
 
@@ -42,9 +41,6 @@ embedded GPG-encrypted data using the :py:mod:`GPG renderer
 <salt.renderers.gpg>`.
 """
 
-# import python libs
-from __future__ import absolute_import, print_function, unicode_literals
-
 import logging
 
 import salt.exceptions
@@ -98,7 +94,7 @@ def _get_values(profile=None):
                 ret = salt.utils.dictupdate.merge(
                     ret, contents, **profile.get("merge", {})
                 )
-        except IOError:
+        except OSError:
             log.error("File '%s' not found ", fname)
         except TypeError as exc:
             log.error("Error deserializing sdb file '%s': %s", fname, exc)
