@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Management of Jenkins
 =====================
@@ -7,10 +6,8 @@ Management of Jenkins
 
 """
 
-# Import Python libs
-from __future__ import absolute_import, print_function, unicode_literals
-
 import difflib
+import io
 import logging
 
 # Import XML parser
@@ -20,10 +17,6 @@ import salt.utils.files
 import salt.utils.stringutils
 from salt.exceptions import CommandExecutionError
 
-# Import Salt libs
-from salt.ext import six
-from salt.ext.six.moves import zip
-
 log = logging.getLogger(__name__)
 
 
@@ -62,12 +55,12 @@ def present(name, config=None, **kwargs):
         "name": name,
         "result": True,
         "changes": {},
-        "comment": ["Job {0} is up to date.".format(name)],
+        "comment": [f"Job {name} is up to date."],
     }
 
     if __salt__["jenkins.job_exists"](name):
         _current_job_config = __salt__["jenkins.get_job_config"](name)
-        buf = six.moves.StringIO(_current_job_config)
+        buf = io.StringIO(_current_job_config)
         oldXML = ET.fromstring(buf.read())
 
         cached_source_path = __salt__["cp.cache_file"](config, __env__)
@@ -85,7 +78,7 @@ def present(name, config=None, **kwargs):
                 return _fail(ret, exc.strerror)
             else:
                 ret["changes"] = "".join(diff)
-                ret["comment"].append("Job '{0}' updated.".format(name))
+                ret["comment"].append(f"Job '{name}' updated.")
 
     else:
         cached_source_path = __salt__["cp.cache_file"](config, __env__)
@@ -97,10 +90,10 @@ def present(name, config=None, **kwargs):
         except CommandExecutionError as exc:
             return _fail(ret, exc.strerror)
 
-        buf = six.moves.StringIO(new_config_xml)
+        buf = io.StringIO(new_config_xml)
         diff = difflib.unified_diff("", buf.readlines(), lineterm="")
         ret["changes"][name] = "".join(diff)
-        ret["comment"].append("Job '{0}' added.".format(name))
+        ret["comment"].append(f"Job '{name}' added.")
 
     ret["comment"] = "\n".join(ret["comment"])
     return ret
@@ -121,7 +114,7 @@ def absent(name, **kwargs):
         except CommandExecutionError as exc:
             return _fail(ret, exc.strerror)
         else:
-            ret["comment"] = "Job '{0}' deleted.".format(name)
+            ret["comment"] = f"Job '{name}' deleted."
     else:
-        ret["comment"] = "Job '{0}' already absent.".format(name)
+        ret["comment"] = f"Job '{name}' already absent."
     return ret
