@@ -13,6 +13,12 @@ from salt.exceptions import SaltException
 
 log = logging.getLogger(__name__)
 
+__deprecated__ = (
+    3009,
+    "zabbix",
+    "https://github.com/salt-extensions/saltext-zabbix",
+)
+
 
 def __virtual__():
     """
@@ -95,7 +101,7 @@ def present(name, params, **kwargs):
 
             if dry_run:
                 ret["result"] = True
-                ret["comment"] = 'Zabbix Value map "{}" would be fixed.'.format(name)
+                ret["comment"] = f'Zabbix Value map "{name}" would be fixed.'
                 ret["changes"] = {
                     name: {
                         "old": (
@@ -119,32 +125,32 @@ def present(name, params, **kwargs):
                 )
                 if valuemap_update:
                     ret["result"] = True
-                    ret["comment"] = 'Zabbix Value map "{}" updated.'.format(name)
+                    ret["comment"] = f'Zabbix Value map "{name}" updated.'
                     ret["changes"] = {
                         name: {
                             "old": (
                                 'Zabbix Value map "{}" differed '
                                 "in following parameters: {}".format(name, diff_params)
                             ),
-                            "new": 'Zabbix Value map "{}" fixed.'.format(name),
+                            "new": f'Zabbix Value map "{name}" fixed.',
                         }
                     }
 
         else:
             ret["result"] = True
-            ret[
-                "comment"
-            ] = 'Zabbix Value map "{}" already exists and corresponds to a definition.'.format(
-                name
+            ret["comment"] = (
+                'Zabbix Value map "{}" already exists and corresponds to a definition.'.format(
+                    name
+                )
             )
 
     else:
         if dry_run:
             ret["result"] = True
-            ret["comment"] = 'Zabbix Value map "{}" would be created.'.format(name)
+            ret["comment"] = f'Zabbix Value map "{name}" would be created.'
             ret["changes"] = {
                 name: {
-                    "old": 'Zabbix Value map "{}" does not exist.'.format(name),
+                    "old": f'Zabbix Value map "{name}" does not exist.',
                     "new": (
                         'Zabbix Value map "{}" would be created '
                         "according definition.".format(name)
@@ -163,10 +169,10 @@ def present(name, params, **kwargs):
 
             if valuemap_create:
                 ret["result"] = True
-                ret["comment"] = 'Zabbix Value map "{}" created.'.format(name)
+                ret["comment"] = f'Zabbix Value map "{name}" created.'
                 ret["changes"] = {
                     name: {
-                        "old": 'Zabbix Value map "{}" did not exist.'.format(name),
+                        "old": f'Zabbix Value map "{name}" did not exist.',
                         "new": (
                             'Zabbix Value map "{}" created according definition.'.format(
                                 name
@@ -205,15 +211,15 @@ def absent(name, **kwargs):
 
     if not object_id:
         ret["result"] = True
-        ret["comment"] = 'Zabbix Value map "{}" does not exist.'.format(name)
+        ret["comment"] = f'Zabbix Value map "{name}" does not exist.'
     else:
         if dry_run:
             ret["result"] = True
-            ret["comment"] = 'Zabbix Value map "{}" would be deleted.'.format(name)
+            ret["comment"] = f'Zabbix Value map "{name}" would be deleted.'
             ret["changes"] = {
                 name: {
-                    "old": 'Zabbix Value map "{}" exists.'.format(name),
-                    "new": 'Zabbix Value map "{}" would be deleted.'.format(name),
+                    "old": f'Zabbix Value map "{name}" exists.',
+                    "new": f'Zabbix Value map "{name}" would be deleted.',
                 }
             }
         else:
@@ -223,11 +229,11 @@ def absent(name, **kwargs):
 
             if valuemap_delete:
                 ret["result"] = True
-                ret["comment"] = 'Zabbix Value map "{}" deleted.'.format(name)
+                ret["comment"] = f'Zabbix Value map "{name}" deleted.'
                 ret["changes"] = {
                     name: {
-                        "old": 'Zabbix Value map "{}" existed.'.format(name),
-                        "new": 'Zabbix Value map "{}" deleted.'.format(name),
+                        "old": f'Zabbix Value map "{name}" existed.',
+                        "new": f'Zabbix Value map "{name}" deleted.',
                     }
                 }
 
