@@ -2,7 +2,6 @@
 Functions for manipulating or otherwise processing strings
 """
 
-
 import base64
 import difflib
 import errno
@@ -14,7 +13,6 @@ import shlex
 import time
 import unicodedata
 
-from salt.ext.six.moves import range  # pylint: disable=redefined-builtin
 from salt.utils.decorators.jinja import jinja_filter
 
 log = logging.getLogger(__name__)
@@ -51,7 +49,7 @@ def to_bytes(s, encoding=None, errors="strict"):
         # raised, otherwise we would have already returned (or raised some
         # other exception).
         raise exc  # pylint: disable=raising-bad-type
-    raise TypeError("expected str, bytes, or bytearray not {}".format(type(s)))
+    raise TypeError(f"expected str, bytes, or bytearray not {type(s)}")
 
 
 def to_str(s, encoding=None, errors="strict", normalize=False):
@@ -74,8 +72,6 @@ def to_str(s, encoding=None, errors="strict", normalize=False):
     if not encoding:
         raise ValueError("encoding cannot be empty")
 
-    # This shouldn't be six.string_types because if we're on PY2 and we already
-    # have a string, we should just return it.
     if isinstance(s, str):
         return _normalize(s)
 
@@ -91,7 +87,7 @@ def to_str(s, encoding=None, errors="strict", normalize=False):
         # raised, otherwise we would have already returned (or raised some
         # other exception).
         raise exc  # pylint: disable=raising-bad-type
-    raise TypeError("expected str, bytes, or bytearray not {}".format(type(s)))
+    raise TypeError(f"expected str, bytes, or bytearray not {type(s)}")
 
 
 def to_unicode(s, encoding=None, errors="strict", normalize=False):
@@ -115,7 +111,7 @@ def to_unicode(s, encoding=None, errors="strict", normalize=False):
         return _normalize(s)
     elif isinstance(s, (bytes, bytearray)):
         return _normalize(to_str(s, encoding, errors))
-    raise TypeError("expected str, bytes, or bytearray not {}".format(type(s)))
+    raise TypeError(f"expected str, bytes, or bytearray not {type(s)}")
 
 
 @jinja_filter("str_to_num")
@@ -185,31 +181,40 @@ def is_binary(data):
     """
     Detects if the passed string of data is binary or text
     """
+
     if not data or not isinstance(data, ((str,), bytes)):
         return False
 
-    if isinstance(data, bytes):
-        if b"\0" in data:
-            return True
-    elif "\0" in data:
+    if not isinstance(data, bytes):
+        data = to_bytes(data)
+
+    if b"\0" in data:
         return True
 
-    text_characters = "".join([chr(x) for x in range(32, 127)] + list("\n\r\t\b"))
-    # Get the non-text characters (map each character to itself then use the
-    # 'remove' option to get rid of the text characters.)
-    if isinstance(data, bytes):
-        import salt.utils.data
+    def int2byte(x):
+        return bytes((x,))
 
-        nontext = data.translate(None, salt.utils.data.encode(text_characters))
-    else:
-        trans = "".maketrans("", "", text_characters)
-        nontext = data.translate(trans)
+    # Defines the text characters as being the ASCII characters plus a few
+    # control characters (newline, carriage return, tab, formfeed and backspace)
+    text_characters = b"".join(int2byte(i) for i in range(32, 127)) + b"\n\r\t\f\b"
+
+    try:
+        # Defines the range of values used by UTF-8 multibyte characters
+        mb_utf8_characters = b"".join(int2byte(i) for i in range(128, 255))
+
+        data.decode(__salt_system_encoding__)
+
+        text_characters = text_characters + mb_utf8_characters
+    except UnicodeDecodeError as err:
+        # This handles truncated characters at end of string
+        if err.reason == "unexpected end of data":
+            text_characters = text_characters + mb_utf8_characters
+
+    nontext = data.translate(None, text_characters)
 
     # If more than 30% non-text characters, then
     # this is considered binary data
-    if float(len(nontext)) / len(data) > 0.30:
-        return True
-    return False
+    return float(len(nontext)) / len(data) > 0.30
 
 
 @jinja_filter("random_str")
@@ -226,31 +231,36 @@ def contains_whitespace(text):
     return any(x.isspace() for x in text)
 
 
-def human_to_bytes(size):
+@jinja_filter("human_to_bytes")
+def human_to_bytes(size, default_unit="B", handle_metric=False):
     """
-    Given a human-readable byte string (e.g. 2G, 30M),
+    Given a human-readable byte string (e.g. 2G, 30MB, 64KiB),
     return the number of bytes.  Will return 0 if the argument has
     unexpected form.
 
     .. versionadded:: 2018.3.0
+    .. versionchanged:: 3005
     """
-    sbytes = size[:-1]
-    unit = size[-1]
-    if sbytes.isdigit():
-        sbytes = int(sbytes)
-        if unit == "P":
-            sbytes *= 1125899906842624
-        elif unit == "T":
-            sbytes *= 1099511627776
-        elif unit == "G":
-            sbytes *= 1073741824
-        elif unit == "M":
-            sbytes *= 1048576
-        else:
-            sbytes = 0
-    else:
-        sbytes = 0
-    return sbytes
+    m = re.match(r"(?P<value>[0-9.]*)\s*(?P<unit>.*)$", str(size).strip())
+    value = m.group("value")
+    # default unit
+    unit = m.group("unit").lower() or default_unit.lower()
+    try:
+        value = int(value)
+    except ValueError:
+        try:
+            value = float(value)
+        except ValueError:
+            return 0
+    # flag for base ten
+    dec = False
+    if re.match(r"[kmgtpezy]b$", unit):
+        dec = True if handle_metric else False
+    elif not re.match(r"(b|[kmgtpezy](ib)?)$", unit):
+        return 0
+    p = "bkmgtpezy".index(unit[0])
+    value *= 10 ** (p * 3) if dec else 2 ** (p * 10)
+    return int(value)
 
 
 def build_whitespace_split_regex(text):
@@ -299,7 +309,7 @@ def build_whitespace_split_regex(text):
     for line in text.splitlines():
         parts = [re.escape(s) for s in __build_parts(line)]
         regex += r"(?:[\s]+)?{}(?:[\s]+)?".format(r"(?:[\s]+)?".join(parts))
-    return r"(?m)^{}$".format(regex)
+    return rf"(?m)^{regex}$"
 
 
 def expr_match(line, expr):
@@ -321,7 +331,7 @@ def expr_match(line, expr):
         if fnmatch.fnmatch(line, expr):
             return True
         try:
-            if re.match(r"\A{}\Z".format(expr), line):
+            if re.match(rf"\A{expr}\Z", line):
                 return True
         except re.error:
             pass
@@ -458,7 +468,7 @@ def print_cli(msg, retries=10, step=0.01):
             except UnicodeEncodeError:
                 print(msg.encode("utf-8"))
         except OSError as exc:
-            err = "{}".format(exc)
+            err = f"{exc}"
             if exc.errno != errno.EPIPE:
                 if (
                     "temporarily unavailable" in err or exc.errno in (errno.EAGAIN,)
@@ -521,7 +531,7 @@ def get_diff(a, b, *args, **kwargs):
             salt.utils.data.decode_list(a, encoding=encoding),
             salt.utils.data.decode_list(b, encoding=encoding),
             *args,
-            **kwargs
+            **kwargs,
         )
     )
 
