@@ -88,6 +88,7 @@ except ImportError:
 try:
     import backports
 except ImportError:
+    # Python 3.13+ doesn't have backports package
     backports = None
 
 concurrent = None
@@ -288,8 +289,10 @@ def get_tops_python(py_ver, exclude=None, ext_py_ver=None):
         "backports_abc",
         "looseversion",
         "packaging",
-        "backports",
     ]
+    # backports package doesn't exist in Python 3.13+
+    if sys.version_info < (3, 13):
+        mods.append("backports")
     if ext_py_ver and tuple(ext_py_ver) >= (3, 0):
         mods.append("distro")
 
